from typer.testing import CliRunner
from dhruv.cli import app

runner = CliRunner()

def test_hello_command():
    result = runner.invoke(app, ["hello"])
    assert result.exit_code == 0
    assert "Hello from Dhruv!" in result.stdout



import typer
from dhruv.main import hello

app = typer.Typer()

@app.callback()
def callback():
    """
    Dhruv CLI
    """
    pass

@app.command(name="hello")
def hello_cmd():
    """
    Prints a hello message.
    """
    print(hello())

if __name__ == "__main__":
    app()
